;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "tide" "20260219.336"
  "Typescript Interactive Development Environment."
  '((emacs    "25.1")
    (dash     "2.10.0")
    (s        "1.11.0")
    (flycheck "27")
    (cl-lib   "0.5"))
  :url "https://github.com/ananthakumaran/tide"
  :commit "9498c4c7fc97d8042fdff532f47f1dc79ebd163a"
  :revdesc "9498c4c7fc97"
  :keywords '("typescript")
  :authors '(("Anantha kumaran" . "ananthakumaran@gmail.com"))
  :maintainers '(("Anantha kumaran" . "ananthakumaran@gmail.com")))
